# How to contribute to `rcdesign`
Thank you for considering contributing to `rcdesign`.

## Reporting issues


## Submitting patches

### First time setup


### Start coding


### Running the tests


### Running test coverage


### Building the docs


